package com.wechi.adweb.bridge.google.ads.controller;

import com.wechi.adweb.bridge.common.APIStatus;
import com.wechi.adweb.bridge.common.BaseController;
import com.wechi.adweb.bridge.common.OpenAPIRequest;
import com.wechi.adweb.bridge.common.OpenAPIResponse;
import com.wechi.adweb.bridge.exception.BadRequestException;
import com.wechi.adweb.bridge.exception.DataException;
import com.wechi.adweb.bridge.google.ads.dto.CustomerStatsDTO;
import com.wechi.adweb.bridge.google.ads.service.GoogleAdsService;
import com.wechi.adweb.bridge.util.JsonUtils;

import io.swagger.v3.oas.annotations.Operation;

import lombok.extern.slf4j.Slf4j;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @author wfansh
 */
@Slf4j
@RestController
@RequestMapping("/api/google/ads")
public class GoogleAdsController extends BaseController {

    @Autowired private GoogleAdsService googleAdsService;

    @Operation(summary = "Get customer stats by customer ID.")
    @PostMapping("/customerStats")
    @ResponseBody
    public OpenAPIResponse<CustomerStatsDTO> getCustomerStats(
            @RequestBody OpenAPIRequest<String> apiRequest)
            throws BadRequestException, DataException {
        long start = System.currentTimeMillis();
        log.info("****** getCustomerStats() ****** apiRequest = {}", JsonUtils.toJson(apiRequest));
        String customerId = apiRequest.getData();

        // 1. Validates the request parameters.
        if (StringUtils.isEmpty(customerId)) {
            throw new BadRequestException(apiRequest);
        }

        // 2. Executes the API request.
        CustomerStatsDTO customerStats = googleAdsService.getCustomerStats(customerId);
        log.info(
                "****** getCustomerStats() ****** duration = {} seconds", getElapsedSeconds(start));
        return OpenAPIResponse.<CustomerStatsDTO>builder()
                .status(APIStatus.SUCCESS)
                .data(customerStats)
                .build();
    }
}
